.wrapper {
    width: 800px;
    margin: 0 auto;
}

input,button,select,textarea{outline:none}

.name a {
    font-size: 48px;
    text-decoration: none;
}

aside {
    margin-bottom: 1.2em;
}

.title h2 {
    margin: 0.83em 0 0;
}

.center {
    display: block;
    margin: 0 auto;
    text-align: center;
}

nav.nav {
    border-bottom: 3px solid #EEE;
    padding-bottom: 20px;
    margin-bottom: 20px;
}

header > nav > a {
    display: inline-block;
    padding: 0 30px
}

.article, .archives {
    padding-bottom: 30px;
    margin-bottom: 40px;
    border-bottom: 2px solid #EEE;
}

h1,h2,h3,h4,h5,h6 {
    font-weight: 100;
}

.paging {
    display: table;
    width: 100%;
    padding-bottom: 20px;
}

.next {
    float: right;
    text-decoration: none;
}

.prev {
    float: left;
    text-decoration: none;
}


.content {
    margin: 0 40px;
}

.archive {
    font-size: 24px;
    width: 100%;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden;
    display: inline-block;
}

.archive > span {
    margin-right: 30px;
}

.tags {
    color: gray;
    font-size: 0.9em;
}

a.tag {
    margin: 0 3px;
    color: gray;
}

a.publish {
    text-decoration: none;
}

textarea.post {
    resize: vertical;
    display: inline-block;
    width: 100%;
    height: 400px;
    border: 3px solid #CCC;
    margin-left: -3px;
    font-size: 18px;
    margin-bottom: 30px;
    font-family:  "Georgia", "Xin Gothic", "Hiragino Sans GB", "WenQuanYi Micro Hei", "Microsoft YaHei", "SimSun", sans-serif;
}

@media screen and (max-width: 980px) {
    .wrapper {
        width: 100%;
    }

    .content {
        margin: 0;
    }
}