{% extends 'layout.html' %}

{% block content %}
<article class="article">
    <h2 class="center title">Weclome</h2>
    <article class="content">
    <p>Hello, I'm {{ site_owner }}. This is my own about me site. You can understand me here.</p>
    </article>
</article>
{% endblock %}
